==> koffice-trinity-3.5.13.2.tar.xz: koffice-trinity-3.5.13.2/kexi/core/kexisharedactionhost_p.h <==
/* This file is part of the KDE project
   Copyright (C) 2004 Jaroslaw Staniek <js@iidea.pl>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KEXISHAREDACTIONHOST_P_H
#define KEXISHAREDACTIONHOST_P_H

#include <tqobject.h>
#include <tqptrdict.h>
#include <tqsignalmapper.h>

#include <kmainwindow.h>

#include "kexiactionproxy.h"

class KexiSharedActionHost;

class KexiVolatileActionData
{
	public:
		KexiVolatileActionData() { plugged=false; }
//		KAction *kaction;
		bool plugged : 1;
};

//! @internal
class KEXICORE_EXPORT KexiSharedActionHostPrivate : public TQObject
{
	Q_OBJECT
  TQ_OBJECT

	public:
		KexiSharedActionHostPrivate(KexiSharedActionHost *h);

	public slots:
		void slotAction(const TQString& act_id);

	public:
		TQPtrDict<KexiActionProxy> actionProxies;
		KMainWindow *mainWin;
		KActionPtrList sharedActions;
		TQSignalMapper actionMapper;
		TQPtrDict<KexiVolatileActionData> volatileActions;
		TQAsciiDict<TQWidget> enablers;

		KexiSharedActionHost *host;
};

#endif

==> koffice-trinity_14.0.12.orig.tar.xz: koffice-trinity-14.0.12/kexi/core/kexisharedactionhost_p.h <==
/* This file is part of the KDE project
   Copyright (C) 2004 Jaroslaw Staniek <js@iidea.pl>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KEXISHAREDACTIONHOST_P_H
#define KEXISHAREDACTIONHOST_P_H

#include <tqobject.h>
#include <tqptrdict.h>
#include <tqsignalmapper.h>

#include <tdemainwindow.h>

#include "kexiactionproxy.h"

class KexiSharedActionHost;

class KexiVolatileActionData
{
	public:
		KexiVolatileActionData() { plugged=false; }
//		TDEAction *tdeaction;
		bool plugged : 1;
};

//! @internal
class KEXICORE_EXPORT KexiSharedActionHostPrivate : public TQObject
{
	Q_OBJECT
  

	public:
		KexiSharedActionHostPrivate(KexiSharedActionHost *h);

	public slots:
		void slotAction(const TQString& act_id);

	public:
		TQPtrDict<KexiActionProxy> actionProxies;
		TDEMainWindow *mainWin;
		TDEActionPtrList sharedActions;
		TQSignalMapper actionMapper;
		TQPtrDict<KexiVolatileActionData> volatileActions;
		TQAsciiDict<TQWidget> enablers;

		KexiSharedActionHost *host;
};

#endif
